@@ -1,4 +1,5 @@
-#' Asymptotic Covariance Matrix of the Standardized Parameter Vector
+#' Asymptotic Covariance Matrix of the
+#' Standardized Parameter Vector
 #'
 #' @author Ivan Jacob Agaloos Pesigan
 #'
@@ -9,7 +10,8 @@
 #' @param gammacap Numeric matrix.
 #'   Adjusted asymptotic covariance matrix.
 #' @param gammacap_mvn Numeric matrix.
-#'   Asymptotic covariance matrix of the sample covariance matrix assuming multivariate normal distribution.
+#'   Asymptotic covariance matrix of the sample covariance matrix
+#'   assuming multivariate normal distribution.
 #'
 #' @family Beta Sandwich Functions
 #' @keywords betaSandwich acov internal
@@ -25,7 +27,5 @@
     chol(tjcapinversemvn %*% jcap)
   )
   meat <- tjcapinversemvn %*% gammacap %*% inversemvn %*% jcap
-  return(
-    bread %*% meat %*% bread
-  )
+  bread %*% meat %*% bread
 }
